ConfigDir

Enum ConfigDir 

pub enum ConfigDir {
    Generic(PathBuf),
    Specific {
        path: PathBuf,
        profile: String,
    },
}
Represents a single config-related directory.

Unlike with [ConfigFile]s, the path validity is not checked on instantiation. But given that the filesystem is completely external to the application, the existence or validity of any given path cannot be assumed anyway.

Variants



Generic(PathBuf)

A directory that is not associated with an AppProfile.



Specific

A directory that is associated with an AppProfile of the given name.

Fields

path: PathBuf

The path to the directory.

profile: String

The associated profile name.

Implementations

Source

impl ConfigDir

pub fn at(path: PathBuf) -> Self

Creates a ConfigDir from the given PathBuf, if the path points to a workable directory.

pub fn make_with_profile(path: PathBuf, known_profile: Option<&str>) -> Self

Creates a ConfigDir from the given PathBuf, if the path points to a workable directory, optionally applying the given known profile name.

pub fn make_capturing_profile(path: PathBuf) -> Self

Creates a ConfigDir from the given PathBuf, attempting to capture its name as a profile name. If the name cannot be captured (e.g., if the path doesn’t exist), the generic variant is returned.

Source

impl ConfigDir

pub fn name(&self) -> Option<&str>

Reports the name of this directory, if it is readable.

pub fn is_generic(&self) -> bool

Reports whether this ConfigDir is applicable regardless of the active AppProfile.

pub fn is_specific(&self) -> bool

Reports whether this ConfigDir is applicable only to a particular AppProfile.

pub fn path(&self) -> &PathBuf

Returns a reference to the internally held PathBuf.

pub fn profile(&self) -> Option<&str>

Returns a reference to the internally held profile name (if this variant is specific).

pub fn applies_to_active_profile(&self) -> bool

Reports whether this ConfigDir applies to the active AppProfile.

pub fn applies_to(&self, profile: impl AsRef<AppProfile>) -> bool

Reports whether this ConfigDir applies to the given AppProfile.

A generic config file (without a profile name in its file name) applies to any profile by default. A specific config file (with a profile name in its file name) applies to the given profile if the profile name matches.

pub fn expand(&self, profile: Option<&str>) -> Vec<ConfigEntry>

Expands this directory into a vector of nested ConfigEntrys.